@@ -44,7 +44,7 @@ class BurnupInput:
         else:
             file.write(f'dep butot \n')
             for burnup in self.butot:
-                file.write(f'{burnup:10.5E}')
+                file.write(f'{burnup:10.5E} \n')
 
     def compile(self, filename):
         with open(filename, 'w') as file:
