@@ -38,13 +38,11 @@ class Cell:
 
     def __add__(self, other):
         if type(other) == str:
-            _cell = Cell(self.name[1:], self.universe, self.material, self.surfaces,
-                         fill=self.fill, delimiter=self.delimiter)
+            _cell = Cell(self.name[1:], self.universe, self.material, self.surfaces, delimiter=self.delimiter)
             _cell.line += f'{self.delimiter}{other}'
             return _cell
         elif type(other) == Cell:
-            _cell = Cell(self.name[1:], self.universe, self.material, self.surfaces,
-                         fill=self.fill, delimiter=self.delimiter)
+            _cell = Cell(self.name[1:], self.universe, self.material, self.surfaces, delimiter=self.delimiter)
             _cell.line += f'{self.delimiter}{other.name}'
             return _cell
         else:
@@ -53,13 +51,11 @@ class Cell:
 
     def __sub__(self, other):
         if type(other) == str:
-            _cell = Cell(self.name[1:], self.universe, self.material, self.surfaces,
-                         fill=self.fill, delimiter=self.delimiter)
+            _cell = Cell(self.name[1:], self.universe, self.material, self.surfaces, delimiter=self.delimiter)
             _cell.line += f'{self.delimiter}-{other}'
             return _cell
         elif type(other) == Cell:
-            _cell = Cell(self.name[1:], self.universe, self.material, self.surfaces,
-                         fill=self.fill, delimiter=self.delimiter)
+            _cell = Cell(self.name[1:], self.universe, self.material, self.surfaces, delimiter=self.delimiter)
             _cell.line += f'{self.delimiter}#{other.name}'
             return _cell
         elif type(other) == list:
@@ -83,7 +79,7 @@ class Cell:
 
 if __name__ == '__main__':
     c = Cell('name', 'uni', 'mat', ['1', '2'])
-    c1 = Cell('name1', 'uni', 'mat', ['1', '2'])
+    c1 = Cell('name1', 'uni', 'mat', ['1', '2'], fill=True)
     c2 = Cell('name2', 'uni', 'mat', ['1', '2'])
 
     c3 = c1 + c2
